# coding: utf-8

"""
    Vero Public API's

    The VeRO API has methods that allow owners of an intellectual property to report eBay listings that infringe on their intellectual property rights. It contains methods to report a listing, retrieve supported VeRO reason codes, and retrieve the status of submitted and items.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ReportItemDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'brand': 'str',
        'copy_email_to_rights_owner': 'bool',
        'countries': 'list[str]',
        'detailed_message': 'str',
        'item_id': 'str',
        'message_to_seller': 'str',
        'patent': 'str',
        'regions': 'list[str]',
        'vero_reason_code_id': 'str'
    }

    attribute_map = {
        'brand': 'brand',
        'copy_email_to_rights_owner': 'copyEmailToRightsOwner',
        'countries': 'countries',
        'detailed_message': 'detailedMessage',
        'item_id': 'itemId',
        'message_to_seller': 'messageToSeller',
        'patent': 'patent',
        'regions': 'regions',
        'vero_reason_code_id': 'veroReasonCodeId'
    }

    def __init__(self, brand=None, copy_email_to_rights_owner=None, countries=None, detailed_message=None, item_id=None, message_to_seller=None, patent=None, regions=None, vero_reason_code_id=None):  # noqa: E501
        """ReportItemDetails - a model defined in Swagger"""  # noqa: E501
        self._brand = None
        self._copy_email_to_rights_owner = None
        self._countries = None
        self._detailed_message = None
        self._item_id = None
        self._message_to_seller = None
        self._patent = None
        self._regions = None
        self._vero_reason_code_id = None
        self.discriminator = None
        if brand is not None:
            self.brand = brand
        if copy_email_to_rights_owner is not None:
            self.copy_email_to_rights_owner = copy_email_to_rights_owner
        if countries is not None:
            self.countries = countries
        if detailed_message is not None:
            self.detailed_message = detailed_message
        if item_id is not None:
            self.item_id = item_id
        if message_to_seller is not None:
            self.message_to_seller = message_to_seller
        if patent is not None:
            self.patent = patent
        if regions is not None:
            self.regions = regions
        if vero_reason_code_id is not None:
            self.vero_reason_code_id = vero_reason_code_id

    @property
    def brand(self):
        """Gets the brand of this ReportItemDetails.  # noqa: E501

        The brand name of the item being reported for VeRO violation.<br><br><b>Max length:</b> 50 characters  # noqa: E501

        :return: The brand of this ReportItemDetails.  # noqa: E501
        :rtype: str
        """
        return self._brand

    @brand.setter
    def brand(self, brand):
        """Sets the brand of this ReportItemDetails.

        The brand name of the item being reported for VeRO violation.<br><br><b>Max length:</b> 50 characters  # noqa: E501

        :param brand: The brand of this ReportItemDetails.  # noqa: E501
        :type: str
        """

        self._brand = brand

    @property
    def copy_email_to_rights_owner(self):
        """Gets the copy_email_to_rights_owner of this ReportItemDetails.  # noqa: E501

        If the VeRO Program member wants a copy of the Notice of Claimed Infringement (NOCI) document sent to their email address, this field should be included in the request and set to <code>true</code>. This same document is automatically sent to the seller of the reported item.<br><br>As this field defaults to <code>true</b>, the report will be automatically emailed if this field is omitted.<br><br><b>Default:</b> true  # noqa: E501

        :return: The copy_email_to_rights_owner of this ReportItemDetails.  # noqa: E501
        :rtype: bool
        """
        return self._copy_email_to_rights_owner

    @copy_email_to_rights_owner.setter
    def copy_email_to_rights_owner(self, copy_email_to_rights_owner):
        """Sets the copy_email_to_rights_owner of this ReportItemDetails.

        If the VeRO Program member wants a copy of the Notice of Claimed Infringement (NOCI) document sent to their email address, this field should be included in the request and set to <code>true</code>. This same document is automatically sent to the seller of the reported item.<br><br>As this field defaults to <code>true</b>, the report will be automatically emailed if this field is omitted.<br><br><b>Default:</b> true  # noqa: E501

        :param copy_email_to_rights_owner: The copy_email_to_rights_owner of this ReportItemDetails.  # noqa: E501
        :type: bool
        """

        self._copy_email_to_rights_owner = copy_email_to_rights_owner

    @property
    def countries(self):
        """Gets the countries of this ReportItemDetails.  # noqa: E501

        If the infringement type stated in the <b>VeroReasonCodeId</b> has anything to do with which country the item is being shipped to, each country that would trigger this infringement type should be specified in this comma-delimited array.<br><br>This field is required when the <b>veroReasonCodeId</b> is <code>9037</code> (Item(s) is unlawful importation of product bearing trademark).  # noqa: E501

        :return: The countries of this ReportItemDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._countries

    @countries.setter
    def countries(self, countries):
        """Sets the countries of this ReportItemDetails.

        If the infringement type stated in the <b>VeroReasonCodeId</b> has anything to do with which country the item is being shipped to, each country that would trigger this infringement type should be specified in this comma-delimited array.<br><br>This field is required when the <b>veroReasonCodeId</b> is <code>9037</code> (Item(s) is unlawful importation of product bearing trademark).  # noqa: E501

        :param countries: The countries of this ReportItemDetails.  # noqa: E501
        :type: list[str]
        """

        self._countries = countries

    @property
    def detailed_message(self):
        """Gets the detailed_message of this ReportItemDetails.  # noqa: E501

        This field is used to provide further information about the VeRO reason code.<br><br>This field is required when the <b>veroReasonCodeId</b> is <code>9052</code> or <code>7052</code> (Other - Provide details information in additional information box below).<br><br><b>Max length:</b> 1000 characters  # noqa: E501

        :return: The detailed_message of this ReportItemDetails.  # noqa: E501
        :rtype: str
        """
        return self._detailed_message

    @detailed_message.setter
    def detailed_message(self, detailed_message):
        """Sets the detailed_message of this ReportItemDetails.

        This field is used to provide further information about the VeRO reason code.<br><br>This field is required when the <b>veroReasonCodeId</b> is <code>9052</code> or <code>7052</code> (Other - Provide details information in additional information box below).<br><br><b>Max length:</b> 1000 characters  # noqa: E501

        :param detailed_message: The detailed_message of this ReportItemDetails.  # noqa: E501
        :type: str
        """

        self._detailed_message = detailed_message

    @property
    def item_id(self):
        """Gets the item_id of this ReportItemDetails.  # noqa: E501

        The unique identifier of the listing being reported for the alleged infringement.  # noqa: E501

        :return: The item_id of this ReportItemDetails.  # noqa: E501
        :rtype: str
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this ReportItemDetails.

        The unique identifier of the listing being reported for the alleged infringement.  # noqa: E501

        :param item_id: The item_id of this ReportItemDetails.  # noqa: E501
        :type: str
        """

        self._item_id = item_id

    @property
    def message_to_seller(self):
        """Gets the message_to_seller of this ReportItemDetails.  # noqa: E501

        This field is used by the VeRO Program member to provide more details to the seller as to why the item is being reported for the alleged infringement.<br><br><b>Max length:</b> 1000 characters  # noqa: E501

        :return: The message_to_seller of this ReportItemDetails.  # noqa: E501
        :rtype: str
        """
        return self._message_to_seller

    @message_to_seller.setter
    def message_to_seller(self, message_to_seller):
        """Sets the message_to_seller of this ReportItemDetails.

        This field is used by the VeRO Program member to provide more details to the seller as to why the item is being reported for the alleged infringement.<br><br><b>Max length:</b> 1000 characters  # noqa: E501

        :param message_to_seller: The message_to_seller of this ReportItemDetails.  # noqa: E501
        :type: str
        """

        self._message_to_seller = message_to_seller

    @property
    def patent(self):
        """Gets the patent of this ReportItemDetails.  # noqa: E501

        This field is used to specify the number of a product patent that is being violated.<br><br>This field is required when the <b>veroReasonCodeId</b> is <code>9048</code> (Item(s) infringes a valid patent).<br><br><b>Max length:</b> 15 characters  # noqa: E501

        :return: The patent of this ReportItemDetails.  # noqa: E501
        :rtype: str
        """
        return self._patent

    @patent.setter
    def patent(self, patent):
        """Sets the patent of this ReportItemDetails.

        This field is used to specify the number of a product patent that is being violated.<br><br>This field is required when the <b>veroReasonCodeId</b> is <code>9048</code> (Item(s) infringes a valid patent).<br><br><b>Max length:</b> 15 characters  # noqa: E501

        :param patent: The patent of this ReportItemDetails.  # noqa: E501
        :type: str
        """

        self._patent = patent

    @property
    def regions(self):
        """Gets the regions of this ReportItemDetails.  # noqa: E501

        If the infringement type stated in the <b>veroReasonCodeId</b> has anything to do with which geographical region the item is being shipped to, each region that would trigger this infringement type should be specified in this comma-delimited array.  # noqa: E501

        :return: The regions of this ReportItemDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._regions

    @regions.setter
    def regions(self, regions):
        """Sets the regions of this ReportItemDetails.

        If the infringement type stated in the <b>veroReasonCodeId</b> has anything to do with which geographical region the item is being shipped to, each region that would trigger this infringement type should be specified in this comma-delimited array.  # noqa: E501

        :param regions: The regions of this ReportItemDetails.  # noqa: E501
        :type: list[str]
        """

        self._regions = regions

    @property
    def vero_reason_code_id(self):
        """Gets the vero_reason_code_id of this ReportItemDetails.  # noqa: E501

        The unique identifier for the type of claimed infringement.<br><br>Use <a href=\"/api-docs/commerce/vero/resources/vero_reason_code/methods/getVeroReasonCodes\" target=\"_blank \">getVeroReasonCodes</a> to retrieve a list of valid reason codes for a given eBay site.  # noqa: E501

        :return: The vero_reason_code_id of this ReportItemDetails.  # noqa: E501
        :rtype: str
        """
        return self._vero_reason_code_id

    @vero_reason_code_id.setter
    def vero_reason_code_id(self, vero_reason_code_id):
        """Sets the vero_reason_code_id of this ReportItemDetails.

        The unique identifier for the type of claimed infringement.<br><br>Use <a href=\"/api-docs/commerce/vero/resources/vero_reason_code/methods/getVeroReasonCodes\" target=\"_blank \">getVeroReasonCodes</a> to retrieve a list of valid reason codes for a given eBay site.  # noqa: E501

        :param vero_reason_code_id: The vero_reason_code_id of this ReportItemDetails.  # noqa: E501
        :type: str
        """

        self._vero_reason_code_id = vero_reason_code_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ReportItemDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReportItemDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    EDIS public shipping API

    <div class=\"msgbox_important\"><p class=\"msgbox_importantInDiv\" data-mc-autonum=\"&lt;b&gt;&lt;span style=&quot;color: #dd1e31;&quot; class=&quot;mcFormatColor&quot;&gt;Important! &lt;/span&gt;&lt;/b&gt;\"><span class=\"autonumber\"><span><b><span style=\"color: #dd1e31;\" class=\"mcFormatColor\">Important!</span></b></span></span> This method is only available for Greater-China based sellers with an active eDIS account.</p></div><br>This API allows 3rd party developers in the Greater-China area to process package shipping details.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PackageInfoRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'agent_info_request': 'AgentInfoData',
        'consign_preference_id': 'str',
        'incoterm': 'str',
        'items': 'list[ItemRequest]',
        'max_quantity_limit': 'int',
        'package_comment': 'str',
        'package_height': 'float',
        'package_length': 'float',
        'package_weight': 'float',
        'package_width': 'float',
        'ship_from_address_id': 'str',
        'shipping_service_id': 'str',
        'ship_to_address': 'ShipToAddressRequestData',
        'special_service_detail': 'SpecialServiceDetail',
        'value_for_carriage': 'str'
    }

    attribute_map = {
        'agent_info_request': 'agentInfoRequest',
        'consign_preference_id': 'consignPreferenceId',
        'incoterm': 'incoterm',
        'items': 'items',
        'max_quantity_limit': 'maxQuantityLimit',
        'package_comment': 'packageComment',
        'package_height': 'packageHeight',
        'package_length': 'packageLength',
        'package_weight': 'packageWeight',
        'package_width': 'packageWidth',
        'ship_from_address_id': 'shipFromAddressId',
        'shipping_service_id': 'shippingServiceId',
        'ship_to_address': 'shipToAddress',
        'special_service_detail': 'specialServiceDetail',
        'value_for_carriage': 'valueForCarriage'
    }

    def __init__(self, agent_info_request=None, consign_preference_id=None, incoterm=None, items=None, max_quantity_limit=None, package_comment=None, package_height=None, package_length=None, package_weight=None, package_width=None, ship_from_address_id=None, shipping_service_id=None, ship_to_address=None, special_service_detail=None, value_for_carriage=None):  # noqa: E501
        """PackageInfoRequest - a model defined in Swagger"""  # noqa: E501
        self._agent_info_request = None
        self._consign_preference_id = None
        self._incoterm = None
        self._items = None
        self._max_quantity_limit = None
        self._package_comment = None
        self._package_height = None
        self._package_length = None
        self._package_weight = None
        self._package_width = None
        self._ship_from_address_id = None
        self._shipping_service_id = None
        self._ship_to_address = None
        self._special_service_detail = None
        self._value_for_carriage = None
        self.discriminator = None
        if agent_info_request is not None:
            self.agent_info_request = agent_info_request
        if consign_preference_id is not None:
            self.consign_preference_id = consign_preference_id
        if incoterm is not None:
            self.incoterm = incoterm
        if items is not None:
            self.items = items
        if max_quantity_limit is not None:
            self.max_quantity_limit = max_quantity_limit
        if package_comment is not None:
            self.package_comment = package_comment
        if package_height is not None:
            self.package_height = package_height
        if package_length is not None:
            self.package_length = package_length
        if package_weight is not None:
            self.package_weight = package_weight
        if package_width is not None:
            self.package_width = package_width
        if ship_from_address_id is not None:
            self.ship_from_address_id = ship_from_address_id
        if shipping_service_id is not None:
            self.shipping_service_id = shipping_service_id
        if ship_to_address is not None:
            self.ship_to_address = ship_to_address
        if special_service_detail is not None:
            self.special_service_detail = special_service_detail
        if value_for_carriage is not None:
            self.value_for_carriage = value_for_carriage

    @property
    def agent_info_request(self):
        """Gets the agent_info_request of this PackageInfoRequest.  # noqa: E501


        :return: The agent_info_request of this PackageInfoRequest.  # noqa: E501
        :rtype: AgentInfoData
        """
        return self._agent_info_request

    @agent_info_request.setter
    def agent_info_request(self, agent_info_request):
        """Sets the agent_info_request of this PackageInfoRequest.


        :param agent_info_request: The agent_info_request of this PackageInfoRequest.  # noqa: E501
        :type: AgentInfoData
        """

        self._agent_info_request = agent_info_request

    @property
    def consign_preference_id(self):
        """Gets the consign_preference_id of this PackageInfoRequest.  # noqa: E501

        The unique identifier of the consign address to be associated with the package.<br><br>This ID can be retrieved using the <a href=\"/api-docs/sell/edelivery_international_shipping/resources/consign_preference/methods/getConsignPreferences\" target=\"_blank\">getConsignPreferences</a> method.  # noqa: E501

        :return: The consign_preference_id of this PackageInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._consign_preference_id

    @consign_preference_id.setter
    def consign_preference_id(self, consign_preference_id):
        """Sets the consign_preference_id of this PackageInfoRequest.

        The unique identifier of the consign address to be associated with the package.<br><br>This ID can be retrieved using the <a href=\"/api-docs/sell/edelivery_international_shipping/resources/consign_preference/methods/getConsignPreferences\" target=\"_blank\">getConsignPreferences</a> method.  # noqa: E501

        :param consign_preference_id: The consign_preference_id of this PackageInfoRequest.  # noqa: E501
        :type: str
        """

        self._consign_preference_id = consign_preference_id

    @property
    def incoterm(self):
        """Gets the incoterm of this PackageInfoRequest.  # noqa: E501

        The incoterm information associated with the package.<br><br><b>Supported values</b>:<ul><li><code>DDP</code></li><li><code>DDU</code></li></ul> For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/edelivery_international_shipping/types/api:IncotermEnum'>eBay API documentation</a>  # noqa: E501

        :return: The incoterm of this PackageInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._incoterm

    @incoterm.setter
    def incoterm(self, incoterm):
        """Sets the incoterm of this PackageInfoRequest.

        The incoterm information associated with the package.<br><br><b>Supported values</b>:<ul><li><code>DDP</code></li><li><code>DDU</code></li></ul> For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/edelivery_international_shipping/types/api:IncotermEnum'>eBay API documentation</a>  # noqa: E501

        :param incoterm: The incoterm of this PackageInfoRequest.  # noqa: E501
        :type: str
        """

        self._incoterm = incoterm

    @property
    def items(self):
        """Gets the items of this PackageInfoRequest.  # noqa: E501

        This array is used to specify applicable information about the eBay line item(s) that will be included in the package.  # noqa: E501

        :return: The items of this PackageInfoRequest.  # noqa: E501
        :rtype: list[ItemRequest]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this PackageInfoRequest.

        This array is used to specify applicable information about the eBay line item(s) that will be included in the package.  # noqa: E501

        :param items: The items of this PackageInfoRequest.  # noqa: E501
        :type: list[ItemRequest]
        """

        self._items = items

    @property
    def max_quantity_limit(self):
        """Gets the max_quantity_limit of this PackageInfoRequest.  # noqa: E501

        This field is used to limit the maximum number of parcels used in a single order. If the order has more than one parcel, revise this value to increase the limit.  # noqa: E501

        :return: The max_quantity_limit of this PackageInfoRequest.  # noqa: E501
        :rtype: int
        """
        return self._max_quantity_limit

    @max_quantity_limit.setter
    def max_quantity_limit(self, max_quantity_limit):
        """Sets the max_quantity_limit of this PackageInfoRequest.

        This field is used to limit the maximum number of parcels used in a single order. If the order has more than one parcel, revise this value to increase the limit.  # noqa: E501

        :param max_quantity_limit: The max_quantity_limit of this PackageInfoRequest.  # noqa: E501
        :type: int
        """

        self._max_quantity_limit = max_quantity_limit

    @property
    def package_comment(self):
        """Gets the package_comment of this PackageInfoRequest.  # noqa: E501

        A seller-defined comment about the package.  # noqa: E501

        :return: The package_comment of this PackageInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._package_comment

    @package_comment.setter
    def package_comment(self, package_comment):
        """Sets the package_comment of this PackageInfoRequest.

        A seller-defined comment about the package.  # noqa: E501

        :param package_comment: The package_comment of this PackageInfoRequest.  # noqa: E501
        :type: str
        """

        self._package_comment = package_comment

    @property
    def package_height(self):
        """Gets the package_height of this PackageInfoRequest.  # noqa: E501

        The height of the package in centimeters.  # noqa: E501

        :return: The package_height of this PackageInfoRequest.  # noqa: E501
        :rtype: float
        """
        return self._package_height

    @package_height.setter
    def package_height(self, package_height):
        """Sets the package_height of this PackageInfoRequest.

        The height of the package in centimeters.  # noqa: E501

        :param package_height: The package_height of this PackageInfoRequest.  # noqa: E501
        :type: float
        """

        self._package_height = package_height

    @property
    def package_length(self):
        """Gets the package_length of this PackageInfoRequest.  # noqa: E501

        The length of the package in centimeters.  # noqa: E501

        :return: The package_length of this PackageInfoRequest.  # noqa: E501
        :rtype: float
        """
        return self._package_length

    @package_length.setter
    def package_length(self, package_length):
        """Sets the package_length of this PackageInfoRequest.

        The length of the package in centimeters.  # noqa: E501

        :param package_length: The package_length of this PackageInfoRequest.  # noqa: E501
        :type: float
        """

        self._package_length = package_length

    @property
    def package_weight(self):
        """Gets the package_weight of this PackageInfoRequest.  # noqa: E501

        The weight of the package in grams.  # noqa: E501

        :return: The package_weight of this PackageInfoRequest.  # noqa: E501
        :rtype: float
        """
        return self._package_weight

    @package_weight.setter
    def package_weight(self, package_weight):
        """Sets the package_weight of this PackageInfoRequest.

        The weight of the package in grams.  # noqa: E501

        :param package_weight: The package_weight of this PackageInfoRequest.  # noqa: E501
        :type: float
        """

        self._package_weight = package_weight

    @property
    def package_width(self):
        """Gets the package_width of this PackageInfoRequest.  # noqa: E501

        The width of the package in centimeters.  # noqa: E501

        :return: The package_width of this PackageInfoRequest.  # noqa: E501
        :rtype: float
        """
        return self._package_width

    @package_width.setter
    def package_width(self, package_width):
        """Sets the package_width of this PackageInfoRequest.

        The width of the package in centimeters.  # noqa: E501

        :param package_width: The package_width of this PackageInfoRequest.  # noqa: E501
        :type: float
        """

        self._package_width = package_width

    @property
    def ship_from_address_id(self):
        """Gets the ship_from_address_id of this PackageInfoRequest.  # noqa: E501

        The unique identifier of the ship-from address used for the package.<br><br>Use the <a href=\"/api-docs/sell/edelivery_international_shipping/resources/address_preference/methods/getAddressPreferences\" target=\"_blank\">getAddressPreferences</a> method to retrieve valid ship-from <b>addressId</b> values associated with your account.  # noqa: E501

        :return: The ship_from_address_id of this PackageInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._ship_from_address_id

    @ship_from_address_id.setter
    def ship_from_address_id(self, ship_from_address_id):
        """Sets the ship_from_address_id of this PackageInfoRequest.

        The unique identifier of the ship-from address used for the package.<br><br>Use the <a href=\"/api-docs/sell/edelivery_international_shipping/resources/address_preference/methods/getAddressPreferences\" target=\"_blank\">getAddressPreferences</a> method to retrieve valid ship-from <b>addressId</b> values associated with your account.  # noqa: E501

        :param ship_from_address_id: The ship_from_address_id of this PackageInfoRequest.  # noqa: E501
        :type: str
        """

        self._ship_from_address_id = ship_from_address_id

    @property
    def shipping_service_id(self):
        """Gets the shipping_service_id of this PackageInfoRequest.  # noqa: E501

        The unique identifier of the shipping service being used for the package.<br><br>This value can be retrieved using the <a href=\"/api-docs/sell/edelivery_international_shipping/resources/services/methods/getServices\" target=\"_blank\">getServices</a> method.  # noqa: E501

        :return: The shipping_service_id of this PackageInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._shipping_service_id

    @shipping_service_id.setter
    def shipping_service_id(self, shipping_service_id):
        """Sets the shipping_service_id of this PackageInfoRequest.

        The unique identifier of the shipping service being used for the package.<br><br>This value can be retrieved using the <a href=\"/api-docs/sell/edelivery_international_shipping/resources/services/methods/getServices\" target=\"_blank\">getServices</a> method.  # noqa: E501

        :param shipping_service_id: The shipping_service_id of this PackageInfoRequest.  # noqa: E501
        :type: str
        """

        self._shipping_service_id = shipping_service_id

    @property
    def ship_to_address(self):
        """Gets the ship_to_address of this PackageInfoRequest.  # noqa: E501


        :return: The ship_to_address of this PackageInfoRequest.  # noqa: E501
        :rtype: ShipToAddressRequestData
        """
        return self._ship_to_address

    @ship_to_address.setter
    def ship_to_address(self, ship_to_address):
        """Sets the ship_to_address of this PackageInfoRequest.


        :param ship_to_address: The ship_to_address of this PackageInfoRequest.  # noqa: E501
        :type: ShipToAddressRequestData
        """

        self._ship_to_address = ship_to_address

    @property
    def special_service_detail(self):
        """Gets the special_service_detail of this PackageInfoRequest.  # noqa: E501


        :return: The special_service_detail of this PackageInfoRequest.  # noqa: E501
        :rtype: SpecialServiceDetail
        """
        return self._special_service_detail

    @special_service_detail.setter
    def special_service_detail(self, special_service_detail):
        """Sets the special_service_detail of this PackageInfoRequest.


        :param special_service_detail: The special_service_detail of this PackageInfoRequest.  # noqa: E501
        :type: SpecialServiceDetail
        """

        self._special_service_detail = special_service_detail

    @property
    def value_for_carriage(self):
        """Gets the value_for_carriage of this PackageInfoRequest.  # noqa: E501

        The declared value of a large carriage (a combination of several orders together).  # noqa: E501

        :return: The value_for_carriage of this PackageInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._value_for_carriage

    @value_for_carriage.setter
    def value_for_carriage(self, value_for_carriage):
        """Sets the value_for_carriage of this PackageInfoRequest.

        The declared value of a large carriage (a combination of several orders together).  # noqa: E501

        :param value_for_carriage: The value_for_carriage of this PackageInfoRequest.  # noqa: E501
        :type: str
        """

        self._value_for_carriage = value_for_carriage

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PackageInfoRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PackageInfoRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from ...commerce_media.api.document_api import DocumentApi
from ...commerce_media.api.image_api import ImageApi
from ...commerce_media.api.video_api import VideoApi



# coding: utf-8

"""
    Metadata API

    The Metadata API has operations that retrieve configuration details pertaining to the different eBay marketplaces. In addition to marketplace information, the API also has operations that get information that helps sellers list items on eBay.  # noqa: E501

    OpenAPI spec version: v1.10.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ListingTypePolicy(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'category_id': 'str',
        'category_tree_id': 'str',
        'digital_good_delivery_enabled': 'bool',
        'listing_durations': 'list[ListingDuration]',
        'pickup_drop_off_enabled': 'bool'
    }

    attribute_map = {
        'category_id': 'categoryId',
        'category_tree_id': 'categoryTreeId',
        'digital_good_delivery_enabled': 'digitalGoodDeliveryEnabled',
        'listing_durations': 'listingDurations',
        'pickup_drop_off_enabled': 'pickupDropOffEnabled'
    }

    def __init__(self, category_id=None, category_tree_id=None, digital_good_delivery_enabled=None, listing_durations=None, pickup_drop_off_enabled=None):  # noqa: E501
        """ListingTypePolicy - a model defined in Swagger"""  # noqa: E501
        self._category_id = None
        self._category_tree_id = None
        self._digital_good_delivery_enabled = None
        self._listing_durations = None
        self._pickup_drop_off_enabled = None
        self.discriminator = None
        if category_id is not None:
            self.category_id = category_id
        if category_tree_id is not None:
            self.category_tree_id = category_tree_id
        if digital_good_delivery_enabled is not None:
            self.digital_good_delivery_enabled = digital_good_delivery_enabled
        if listing_durations is not None:
            self.listing_durations = listing_durations
        if pickup_drop_off_enabled is not None:
            self.pickup_drop_off_enabled = pickup_drop_off_enabled

    @property
    def category_id(self):
        """Gets the category_id of this ListingTypePolicy.  # noqa: E501

        The unique identifier of the eBay leaf category for which metadata is being returned.  # noqa: E501

        :return: The category_id of this ListingTypePolicy.  # noqa: E501
        :rtype: str
        """
        return self._category_id

    @category_id.setter
    def category_id(self, category_id):
        """Sets the category_id of this ListingTypePolicy.

        The unique identifier of the eBay leaf category for which metadata is being returned.  # noqa: E501

        :param category_id: The category_id of this ListingTypePolicy.  # noqa: E501
        :type: str
        """

        self._category_id = category_id

    @property
    def category_tree_id(self):
        """Gets the category_tree_id of this ListingTypePolicy.  # noqa: E501

        The unique identifier of the category tree.  # noqa: E501

        :return: The category_tree_id of this ListingTypePolicy.  # noqa: E501
        :rtype: str
        """
        return self._category_tree_id

    @category_tree_id.setter
    def category_tree_id(self, category_tree_id):
        """Sets the category_tree_id of this ListingTypePolicy.

        The unique identifier of the category tree.  # noqa: E501

        :param category_tree_id: The category_tree_id of this ListingTypePolicy.  # noqa: E501
        :type: str
        """

        self._category_tree_id = category_tree_id

    @property
    def digital_good_delivery_enabled(self):
        """Gets the digital_good_delivery_enabled of this ListingTypePolicy.  # noqa: E501

        A <code>true</code> value in this field indicates that the leaf category supports the listing of items (such as gift cards) that can be delivered electronically via a download link or sent to a buyer's email address.  # noqa: E501

        :return: The digital_good_delivery_enabled of this ListingTypePolicy.  # noqa: E501
        :rtype: bool
        """
        return self._digital_good_delivery_enabled

    @digital_good_delivery_enabled.setter
    def digital_good_delivery_enabled(self, digital_good_delivery_enabled):
        """Sets the digital_good_delivery_enabled of this ListingTypePolicy.

        A <code>true</code> value in this field indicates that the leaf category supports the listing of items (such as gift cards) that can be delivered electronically via a download link or sent to a buyer's email address.  # noqa: E501

        :param digital_good_delivery_enabled: The digital_good_delivery_enabled of this ListingTypePolicy.  # noqa: E501
        :type: bool
        """

        self._digital_good_delivery_enabled = digital_good_delivery_enabled

    @property
    def listing_durations(self):
        """Gets the listing_durations of this ListingTypePolicy.  # noqa: E501

        An array of eBay listing types and the supported durations for the corresponding leaf category. If a specific eBay listing type does not appear for a leaf category, it indicates that the category does not support that listing type.  # noqa: E501

        :return: The listing_durations of this ListingTypePolicy.  # noqa: E501
        :rtype: list[ListingDuration]
        """
        return self._listing_durations

    @listing_durations.setter
    def listing_durations(self, listing_durations):
        """Sets the listing_durations of this ListingTypePolicy.

        An array of eBay listing types and the supported durations for the corresponding leaf category. If a specific eBay listing type does not appear for a leaf category, it indicates that the category does not support that listing type.  # noqa: E501

        :param listing_durations: The listing_durations of this ListingTypePolicy.  # noqa: E501
        :type: list[ListingDuration]
        """

        self._listing_durations = listing_durations

    @property
    def pickup_drop_off_enabled(self):
        """Gets the pickup_drop_off_enabled of this ListingTypePolicy.  # noqa: E501

        A true value in this field indicates that items listed in the category (specified in the <b>listingTypePolicies.categoryId</b> field) may be enabled with the 'Click and Collect' feature. With the 'Click and Collect' feature, a buyer can purchase certain items on an eBay site and collect them at a local store. Buyers are notified by eBay once their items are available. A false value in this field indicates that items listed in the category are not eligible for the 'Click and Collect' feature.  # noqa: E501

        :return: The pickup_drop_off_enabled of this ListingTypePolicy.  # noqa: E501
        :rtype: bool
        """
        return self._pickup_drop_off_enabled

    @pickup_drop_off_enabled.setter
    def pickup_drop_off_enabled(self, pickup_drop_off_enabled):
        """Sets the pickup_drop_off_enabled of this ListingTypePolicy.

        A true value in this field indicates that items listed in the category (specified in the <b>listingTypePolicies.categoryId</b> field) may be enabled with the 'Click and Collect' feature. With the 'Click and Collect' feature, a buyer can purchase certain items on an eBay site and collect them at a local store. Buyers are notified by eBay once their items are available. A false value in this field indicates that items listed in the category are not eligible for the 'Click and Collect' feature.  # noqa: E501

        :param pickup_drop_off_enabled: The pickup_drop_off_enabled of this ListingTypePolicy.  # noqa: E501
        :type: bool
        """

        self._pickup_drop_off_enabled = pickup_drop_off_enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ListingTypePolicy, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListingTypePolicy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    EDIS public shipping API

    <div class=\"msgbox_important\"><p class=\"msgbox_importantInDiv\" data-mc-autonum=\"&lt;b&gt;&lt;span style=&quot;color: #dd1e31;&quot; class=&quot;mcFormatColor&quot;&gt;Important! &lt;/span&gt;&lt;/b&gt;\"><span class=\"autonumber\"><span><b><span style=\"color: #dd1e31;\" class=\"mcFormatColor\">Important!</span></b></span></span> This method is only available for Greater-China based sellers with an active eDIS account.</p></div><br>This API allows 3rd party developers in the Greater-China area to process package shipping details.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GetTrackingDetailResponsesData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'city': 'str',
        'country': 'str',
        'description_en': 'str',
        'description_zh': 'str',
        'district': 'str',
        'event_postal_code': 'str',
        'event_time': 'str',
        'province': 'str',
        'status': 'str',
        'tracking_number': 'str'
    }

    attribute_map = {
        'city': 'city',
        'country': 'country',
        'description_en': 'descriptionEn',
        'description_zh': 'descriptionZh',
        'district': 'district',
        'event_postal_code': 'eventPostalCode',
        'event_time': 'eventTime',
        'province': 'province',
        'status': 'status',
        'tracking_number': 'trackingNumber'
    }

    def __init__(self, city=None, country=None, description_en=None, description_zh=None, district=None, event_postal_code=None, event_time=None, province=None, status=None, tracking_number=None):  # noqa: E501
        """GetTrackingDetailResponsesData - a model defined in Swagger"""  # noqa: E501
        self._city = None
        self._country = None
        self._description_en = None
        self._description_zh = None
        self._district = None
        self._event_postal_code = None
        self._event_time = None
        self._province = None
        self._status = None
        self._tracking_number = None
        self.discriminator = None
        if city is not None:
            self.city = city
        if country is not None:
            self.country = country
        if description_en is not None:
            self.description_en = description_en
        if description_zh is not None:
            self.description_zh = description_zh
        if district is not None:
            self.district = district
        if event_postal_code is not None:
            self.event_postal_code = event_postal_code
        if event_time is not None:
            self.event_time = event_time
        if province is not None:
            self.province = province
        if status is not None:
            self.status = status
        if tracking_number is not None:
            self.tracking_number = tracking_number

    @property
    def city(self):
        """Gets the city of this GetTrackingDetailResponsesData.  # noqa: E501

        The city code in which the tracking event occurred.<br><br>See <a href=\"https://www.edisebay.com/open/development-guide-detail?id=36\" target=\"_blank\">商户API地址编码主数据</a> for valid city codes.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :return: The city of this GetTrackingDetailResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this GetTrackingDetailResponsesData.

        The city code in which the tracking event occurred.<br><br>See <a href=\"https://www.edisebay.com/open/development-guide-detail?id=36\" target=\"_blank\">商户API地址编码主数据</a> for valid city codes.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :param city: The city of this GetTrackingDetailResponsesData.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def country(self):
        """Gets the country of this GetTrackingDetailResponsesData.  # noqa: E501

        The two-letter ISO 3166 country code where the tracking event occurred.  # noqa: E501

        :return: The country of this GetTrackingDetailResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this GetTrackingDetailResponsesData.

        The two-letter ISO 3166 country code where the tracking event occurred.  # noqa: E501

        :param country: The country of this GetTrackingDetailResponsesData.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def description_en(self):
        """Gets the description_en of this GetTrackingDetailResponsesData.  # noqa: E501

        The English description of the tracking event.  # noqa: E501

        :return: The description_en of this GetTrackingDetailResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._description_en

    @description_en.setter
    def description_en(self, description_en):
        """Sets the description_en of this GetTrackingDetailResponsesData.

        The English description of the tracking event.  # noqa: E501

        :param description_en: The description_en of this GetTrackingDetailResponsesData.  # noqa: E501
        :type: str
        """

        self._description_en = description_en

    @property
    def description_zh(self):
        """Gets the description_zh of this GetTrackingDetailResponsesData.  # noqa: E501

        The Chinese description of the tracking event.  # noqa: E501

        :return: The description_zh of this GetTrackingDetailResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._description_zh

    @description_zh.setter
    def description_zh(self, description_zh):
        """Sets the description_zh of this GetTrackingDetailResponsesData.

        The Chinese description of the tracking event.  # noqa: E501

        :param description_zh: The description_zh of this GetTrackingDetailResponsesData.  # noqa: E501
        :type: str
        """

        self._description_zh = description_zh

    @property
    def district(self):
        """Gets the district of this GetTrackingDetailResponsesData.  # noqa: E501

        The district code where the tracking event occurred.<br><br>See <a href=\"https://www.edisebay.com/open/development-guide-detail?id=36\" target=\"_blank\">商户API地址编码主数据</a> for valid district codes.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :return: The district of this GetTrackingDetailResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._district

    @district.setter
    def district(self, district):
        """Sets the district of this GetTrackingDetailResponsesData.

        The district code where the tracking event occurred.<br><br>See <a href=\"https://www.edisebay.com/open/development-guide-detail?id=36\" target=\"_blank\">商户API地址编码主数据</a> for valid district codes.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :param district: The district of this GetTrackingDetailResponsesData.  # noqa: E501
        :type: str
        """

        self._district = district

    @property
    def event_postal_code(self):
        """Gets the event_postal_code of this GetTrackingDetailResponsesData.  # noqa: E501

        The postal code of where the tracking event occurred.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :return: The event_postal_code of this GetTrackingDetailResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._event_postal_code

    @event_postal_code.setter
    def event_postal_code(self, event_postal_code):
        """Sets the event_postal_code of this GetTrackingDetailResponsesData.

        The postal code of where the tracking event occurred.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :param event_postal_code: The event_postal_code of this GetTrackingDetailResponsesData.  # noqa: E501
        :type: str
        """

        self._event_postal_code = event_postal_code

    @property
    def event_time(self):
        """Gets the event_time of this GetTrackingDetailResponsesData.  # noqa: E501

        This timestamp the time and date the tracking event occurred.  # noqa: E501

        :return: The event_time of this GetTrackingDetailResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._event_time

    @event_time.setter
    def event_time(self, event_time):
        """Sets the event_time of this GetTrackingDetailResponsesData.

        This timestamp the time and date the tracking event occurred.  # noqa: E501

        :param event_time: The event_time of this GetTrackingDetailResponsesData.  # noqa: E501
        :type: str
        """

        self._event_time = event_time

    @property
    def province(self):
        """Gets the province of this GetTrackingDetailResponsesData.  # noqa: E501

        The province code where the tracking event occurred.<br><br>See <a href=\"https://www.edisebay.com/open/development-guide-detail?id=36\" target=\"_blank\">商户API地址编码主数据</a> for province district codes.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :return: The province of this GetTrackingDetailResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._province

    @province.setter
    def province(self, province):
        """Sets the province of this GetTrackingDetailResponsesData.

        The province code where the tracking event occurred.<br><br>See <a href=\"https://www.edisebay.com/open/development-guide-detail?id=36\" target=\"_blank\">商户API地址编码主数据</a> for province district codes.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :param province: The province of this GetTrackingDetailResponsesData.  # noqa: E501
        :type: str
        """

        self._province = province

    @property
    def status(self):
        """Gets the status of this GetTrackingDetailResponsesData.  # noqa: E501

        The status of the shipment.  # noqa: E501

        :return: The status of this GetTrackingDetailResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this GetTrackingDetailResponsesData.

        The status of the shipment.  # noqa: E501

        :param status: The status of this GetTrackingDetailResponsesData.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def tracking_number(self):
        """Gets the tracking_number of this GetTrackingDetailResponsesData.  # noqa: E501

        The tracking number specified in the request.  # noqa: E501

        :return: The tracking_number of this GetTrackingDetailResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._tracking_number

    @tracking_number.setter
    def tracking_number(self, tracking_number):
        """Sets the tracking_number of this GetTrackingDetailResponsesData.

        The tracking number specified in the request.  # noqa: E501

        :param tracking_number: The tracking_number of this GetTrackingDetailResponsesData.  # noqa: E501
        :type: str
        """

        self._tracking_number = tracking_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetTrackingDetailResponsesData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetTrackingDetailResponsesData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Media API

    The <b>Media API</b> lets sellers to create, upload, and retrieve files, including:<ul><li>images</li><li>videos</li><li>documents (for GPSR regulations)</li></ul>  # noqa: E501

    OpenAPI spec version: v1_beta.4.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CreateDocumentFromUrlRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'document_type': 'str',
        'document_url': 'str',
        'languages': 'list[str]'
    }

    attribute_map = {
        'document_type': 'documentType',
        'document_url': 'documentUrl',
        'languages': 'languages'
    }

    def __init__(self, document_type=None, document_url=None, languages=None):  # noqa: E501
        """CreateDocumentFromUrlRequest - a model defined in Swagger"""  # noqa: E501
        self._document_type = None
        self._document_url = None
        self._languages = None
        self.discriminator = None
        if document_type is not None:
            self.document_type = document_type
        if document_url is not None:
            self.document_url = document_url
        if languages is not None:
            self.languages = languages

    @property
    def document_type(self):
        """Gets the document_type of this CreateDocumentFromUrlRequest.  # noqa: E501

        The type of the document being created. For example, a <code>USER_GUIDE_OR_MANUAL</code> or a <code>SAFETY_DATA_SHEET</code>. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/commerce/media/types/api:DocumentTypeEnum'>eBay API documentation</a>  # noqa: E501

        :return: The document_type of this CreateDocumentFromUrlRequest.  # noqa: E501
        :rtype: str
        """
        return self._document_type

    @document_type.setter
    def document_type(self, document_type):
        """Sets the document_type of this CreateDocumentFromUrlRequest.

        The type of the document being created. For example, a <code>USER_GUIDE_OR_MANUAL</code> or a <code>SAFETY_DATA_SHEET</code>. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/commerce/media/types/api:DocumentTypeEnum'>eBay API documentation</a>  # noqa: E501

        :param document_type: The document_type of this CreateDocumentFromUrlRequest.  # noqa: E501
        :type: str
        """

        self._document_type = document_type

    @property
    def document_url(self):
        """Gets the document_url of this CreateDocumentFromUrlRequest.  # noqa: E501

        The URL of the document being created.<br><br>The document referenced by the URL must be a .pdf, .png, .jpg, or .jpeg file, and must be no larger than 10 MB.  # noqa: E501

        :return: The document_url of this CreateDocumentFromUrlRequest.  # noqa: E501
        :rtype: str
        """
        return self._document_url

    @document_url.setter
    def document_url(self, document_url):
        """Sets the document_url of this CreateDocumentFromUrlRequest.

        The URL of the document being created.<br><br>The document referenced by the URL must be a .pdf, .png, .jpg, or .jpeg file, and must be no larger than 10 MB.  # noqa: E501

        :param document_url: The document_url of this CreateDocumentFromUrlRequest.  # noqa: E501
        :type: str
        """

        self._document_url = document_url

    @property
    def languages(self):
        """Gets the languages of this CreateDocumentFromUrlRequest.  # noqa: E501

        This array shows the language(s) used in the document.  # noqa: E501

        :return: The languages of this CreateDocumentFromUrlRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._languages

    @languages.setter
    def languages(self, languages):
        """Sets the languages of this CreateDocumentFromUrlRequest.

        This array shows the language(s) used in the document.  # noqa: E501

        :param languages: The languages of this CreateDocumentFromUrlRequest.  # noqa: E501
        :type: list[str]
        """

        self._languages = languages

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateDocumentFromUrlRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateDocumentFromUrlRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    EDIS public shipping API

    <div class=\"msgbox_important\"><p class=\"msgbox_importantInDiv\" data-mc-autonum=\"&lt;b&gt;&lt;span style=&quot;color: #dd1e31;&quot; class=&quot;mcFormatColor&quot;&gt;Important! &lt;/span&gt;&lt;/b&gt;\"><span class=\"autonumber\"><span><b><span style=\"color: #dd1e31;\" class=\"mcFormatColor\">Important!</span></b></span></span> This method is only available for Greater-China based sellers with an active eDIS account.</p></div><br>This API allows 3rd party developers in the Greater-China area to process package shipping details.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SpecialServiceDetail(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'insurance_fee': 'str',
        'packaging_type': 'str',
        'signature_type': 'str',
        'special_service_types': 'list[str]'
    }

    attribute_map = {
        'insurance_fee': 'insuranceFee',
        'packaging_type': 'packagingType',
        'signature_type': 'signatureType',
        'special_service_types': 'specialServiceTypes'
    }

    def __init__(self, insurance_fee=None, packaging_type=None, signature_type=None, special_service_types=None):  # noqa: E501
        """SpecialServiceDetail - a model defined in Swagger"""  # noqa: E501
        self._insurance_fee = None
        self._packaging_type = None
        self._signature_type = None
        self._special_service_types = None
        self.discriminator = None
        if insurance_fee is not None:
            self.insurance_fee = insurance_fee
        if packaging_type is not None:
            self.packaging_type = packaging_type
        if signature_type is not None:
            self.signature_type = signature_type
        if special_service_types is not None:
            self.special_service_types = special_service_types

    @property
    def insurance_fee(self):
        """Gets the insurance_fee of this SpecialServiceDetail.  # noqa: E501

        The insurance fee, if applicable, on the package.<br><br>The insurance amount and currency are consistent with the currency of the destination country  # noqa: E501

        :return: The insurance_fee of this SpecialServiceDetail.  # noqa: E501
        :rtype: str
        """
        return self._insurance_fee

    @insurance_fee.setter
    def insurance_fee(self, insurance_fee):
        """Sets the insurance_fee of this SpecialServiceDetail.

        The insurance fee, if applicable, on the package.<br><br>The insurance amount and currency are consistent with the currency of the destination country  # noqa: E501

        :param insurance_fee: The insurance_fee of this SpecialServiceDetail.  # noqa: E501
        :type: str
        """

        self._insurance_fee = insurance_fee

    @property
    def packaging_type(self):
        """Gets the packaging_type of this SpecialServiceDetail.  # noqa: E501

        The package type.<br><br><b>Valid values</b>:<ul><li><code>PAK</code> (limited weight ≤ 2.5KG)</li><li><code>PACKAGE</code> (limited weight 68KG)</li></ul>  # noqa: E501

        :return: The packaging_type of this SpecialServiceDetail.  # noqa: E501
        :rtype: str
        """
        return self._packaging_type

    @packaging_type.setter
    def packaging_type(self, packaging_type):
        """Sets the packaging_type of this SpecialServiceDetail.

        The package type.<br><br><b>Valid values</b>:<ul><li><code>PAK</code> (limited weight ≤ 2.5KG)</li><li><code>PACKAGE</code> (limited weight 68KG)</li></ul>  # noqa: E501

        :param packaging_type: The packaging_type of this SpecialServiceDetail.  # noqa: E501
        :type: str
        """

        self._packaging_type = packaging_type

    @property
    def signature_type(self):
        """Gets the signature_type of this SpecialServiceDetail.  # noqa: E501

        The signature type, if applicable, for the package.<br><br><b>Valid values</b>:<ul><li><code>ISR</code> (Indirect Signature Required)</li><li><code>DSR</code> (Direct Signature Required)</li><li><code>ASR</code> (Adult Signature Required)</li></ul>  # noqa: E501

        :return: The signature_type of this SpecialServiceDetail.  # noqa: E501
        :rtype: str
        """
        return self._signature_type

    @signature_type.setter
    def signature_type(self, signature_type):
        """Sets the signature_type of this SpecialServiceDetail.

        The signature type, if applicable, for the package.<br><br><b>Valid values</b>:<ul><li><code>ISR</code> (Indirect Signature Required)</li><li><code>DSR</code> (Direct Signature Required)</li><li><code>ASR</code> (Adult Signature Required)</li></ul>  # noqa: E501

        :param signature_type: The signature_type of this SpecialServiceDetail.  # noqa: E501
        :type: str
        """

        self._signature_type = signature_type

    @property
    def special_service_types(self):
        """Gets the special_service_types of this SpecialServiceDetail.  # noqa: E501

        Any special service types supported for the package.<br><br> For example, <code>SATURDAY_DELIVERY</code> indicates that the item is eligible for Saturday delivery.  # noqa: E501

        :return: The special_service_types of this SpecialServiceDetail.  # noqa: E501
        :rtype: list[str]
        """
        return self._special_service_types

    @special_service_types.setter
    def special_service_types(self, special_service_types):
        """Sets the special_service_types of this SpecialServiceDetail.

        Any special service types supported for the package.<br><br> For example, <code>SATURDAY_DELIVERY</code> indicates that the item is eligible for Saturday delivery.  # noqa: E501

        :param special_service_types: The special_service_types of this SpecialServiceDetail.  # noqa: E501
        :type: list[str]
        """

        self._special_service_types = special_service_types

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SpecialServiceDetail, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SpecialServiceDetail):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Media API

    The <b>Media API</b> lets sellers to create, upload, and retrieve files, including:<ul><li>images</li><li>videos</li><li>documents (for GPSR regulations)</li></ul>  # noqa: E501

    OpenAPI spec version: v1_beta.4.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ImageResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'expiration_date': 'str',
        'image_url': 'str'
    }

    attribute_map = {
        'expiration_date': 'expirationDate',
        'image_url': 'imageUrl'
    }

    def __init__(self, expiration_date=None, image_url=None):  # noqa: E501
        """ImageResponse - a model defined in Swagger"""  # noqa: E501
        self._expiration_date = None
        self._image_url = None
        self.discriminator = None
        if expiration_date is not None:
            self.expiration_date = expiration_date
        if image_url is not None:
            self.image_url = image_url

    @property
    def expiration_date(self):
        """Gets the expiration_date of this ImageResponse.  # noqa: E501

        The date and time when an unused EPS image will expire and be removed from the EPS server, in Coordinated Universal Time (UTC). As long as an EPS image is being used in an active listing, that image will remain on the EPS server and be accessible.  # noqa: E501

        :return: The expiration_date of this ImageResponse.  # noqa: E501
        :rtype: str
        """
        return self._expiration_date

    @expiration_date.setter
    def expiration_date(self, expiration_date):
        """Sets the expiration_date of this ImageResponse.

        The date and time when an unused EPS image will expire and be removed from the EPS server, in Coordinated Universal Time (UTC). As long as an EPS image is being used in an active listing, that image will remain on the EPS server and be accessible.  # noqa: E501

        :param expiration_date: The expiration_date of this ImageResponse.  # noqa: E501
        :type: str
        """

        self._expiration_date = expiration_date

    @property
    def image_url(self):
        """Gets the image_url of this ImageResponse.  # noqa: E501

        The EPS URL to access the uploaded image. This URL will be used in listing calls to add the image to a listing.  # noqa: E501

        :return: The image_url of this ImageResponse.  # noqa: E501
        :rtype: str
        """
        return self._image_url

    @image_url.setter
    def image_url(self, image_url):
        """Sets the image_url of this ImageResponse.

        The EPS URL to access the uploaded image. This URL will be used in listing calls to add the image to a listing.  # noqa: E501

        :param image_url: The image_url of this ImageResponse.  # noqa: E501
        :type: str
        """

        self._image_url = image_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ImageResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImageResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
